@@ -25,8 +25,8 @@ typedef  int (*gen_2_t)(gen_t,gen_t,enum_t);
 
 typedef struct {
     char *buffP;
-    int currSize;
-    int buffSize;
+    size_t currSize;
+    size_t buffSize;
 } BLOK;
 
 #define STANDARD (BLOK*) 0     
